<?php
if ( !defined( 'ABSPATH' ) ) exit;

if ( !class_exists( 'csPopupSettings' ) ) {
    /**
     * Class to generate the settings field
     *
     */
    class csPopupSettings {
        /**
         * Holds the values to be used in the fields callbacks
         */
        public function __construct(){
            add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
            add_action( 'admin_init', array( $this, 'page_init' ) );
            add_action( 'admin_init', array( $this, 'cs_popup_admin_scripts' ) );


        }
        private $options;
        /*
         * generating the admin  menu
         */
        function add_admin_menu(){
            add_menu_page(
                _x( 'CS Popup Maker', 'Title of admin page that shows popup', 'cs-popup' ),
                _x( 'CS Popup Maker', 'Title of analytics admin menu item', 'cs-popup' ),
                'manage_options',
                'cs-popup',
                array( $this, 'show_admin_popup_setting_page' ),
                'dashicons-format-image',
                '26.2987'
            );
        }

        /**
         * Register and add settings
         */
        public function page_init()
        {
            register_setting(
                'cs-popup-group', // Option group
                'cs-popup', // Option name
                array( $this, 'sanitize' ) // Sanitize
            );

            add_settings_section(
                'cspopup_settings', // ID
                '', // Title
                array( $this, 'print_section_info' ), // Callback
                'cs-popup-page' // Page
            );

            add_settings_field(
                'cs_popup_page', // ID
                'Page', // Title
                array( $this, 'cs_popup_page_callback' ), // Callback
                'cs-popup-page', // Page
                'cspopup_settings' // Section
            );
            add_settings_field(
                'cs_popup_image', // ID
                '', // Title
                array( $this, 'cs_popup_image_callback' ), // Callback
                'cs-popup-page', // Page
                'cspopup_settings' // Section
            );
            add_settings_field(
                'cs_popup_target', // ID
                'Target', // Title
                array( $this, 'cs_popup_target_callback' ), // Callback
                'cs-popup-page', // Page
                'cspopup_settings' // Section
            );
            add_settings_field(
                'cs_popup_active',
                'Show Popup',
                array($this,'cs_popup_active_callback'),
                'cs-popup-page',
                'cspopup_settings'
            );
        }
        /**
         * Get the settings option array and print one of its values
         */
        public function cs_popup_page_callback()
        {
            $options = get_option('cs-popup');
            printf('<select name="cs-popup[cs_popup_page]"><option value="">Select Page</option>');
            printf('<option value="-1" %s>All Pages</option>',($options['cs_popup_page']==-1)?'selected="selected"':'');
            printf('<option value="0" %s>Home Page</option>',($options['cs_popup_page']==0)?'selected="selected"':'');
            foreach(get_pages() as $pg):
                printf('<option value="%s" %s>%s</option>',$pg->ID,($options['cs_popup_page']==$pg->ID)?'selected="selected"':'',$pg->post_title);
                endforeach;
            printf('</select>');
        }
        public function cs_popup_image_callback()
        {
            echo '<div>';
            if($this->options['cs_popup_image']!='')
                echo '<img src="'.$this->options['cs_popup_image'].'" id="cs-popup-image-show" width="100" />';
            else
                echo '<img id="cs-popup-image-show" width="100" />';
            echo "</div>";
            printf(
                '<input type="button" name="cs_popup_image_button" id="cs-popup-image-button" value="Choose Image" />'
            );
            printf(
                '<input type="hidden" class="form-control" id="cs_popup_image" name="cs-popup[cs_popup_image]" value="%s" />',
                isset( $this->options['cs_popup_image'] ) ? esc_attr( $this->options['cs_popup_image']) : ''
            );
        }

        public function cs_popup_target_callback()
        {
            printf(
                '<input type="text" class="form-control" id="title" name="cs-popup[cs_popup_target]" value="%s" />',
                isset( $this->options['cs_popup_target'] ) ? esc_attr( $this->options['cs_popup_target']) : ''
            );
            echo '<p>Target Url when the popup image is clicked</p>';
        }

        public function cs_popup_active_callback()
        {
            printf('<input type="checkbox" name="cs-popup[cs_popup_status]" value="1" %s />',
                (isset($this->options['cs_popup_status']) && $this->options['cs_popup_status']==1)?'checked="checked"':''
            );
        }
        /*
         * showing the setting page in the admin section
         */
        function show_admin_popup_setting_page(){
            $this->options = get_option( 'cs-popup' );
            ?>
            <div class="wrap">
                <h1>Popup Settings</h1>
                <form method="post" action="options.php">
                    <?php
                    // This prints out all hidden setting fields
                    settings_fields( 'cs-popup-group' );
                    do_settings_sections( 'cs-popup-page' );
                    submit_button();
                    ?>
                </form>
            </div>
        <?php
        }
        /**
         * Sanitize each setting field as needed
         *
         * @param array $input Contains all settings fields as array keys
         */
        public function sanitize( $input )
        {
            $new_input = array();


            if( isset( $input['cs_popup_page'] ) )
                $new_input['cs_popup_page'] = sanitize_text_field( $input['cs_popup_page'] );
            if( isset( $input['cs_popup_image'] ) )
                $new_input['cs_popup_image'] = sanitize_text_field( $input['cs_popup_image'] );
            if( isset( $input['cs_popup_target'] ) )
                $new_input['cs_popup_target'] = sanitize_text_field( $input['cs_popup_target'] );
            if(isset($input['cs_popup_status']))
                $new_input['cs_popup_status'] = sanitize_text_field( $input['cs_popup_status'] );

            return $new_input;
        }
        /**
         * Print the Section text
         */
        public function print_section_info()
        {
            print 'Choose the page and image for the popup';
        }
        /*
         * loading the scripts
         */
        function cs_popup_admin_scripts()
        {
            wp_enqueue_media();
            wp_register_script( 'cs_admin', CSP_PLUGIN_URL.'/js/cs-popup-admin.js' , __FILE__ );
            wp_enqueue_script( 'cs_admin' );
        }
    }
}